/*this files is part of vobcopy*/

int get_dvd_name(const char *, char *);
int get_device(char *, char *);
int get_device_on_your_own(char *, char *);
off_t get_vob_size(int , char *);
